from langchain.chat_models import ChatOpenAI
from gpt_index import (
    SimpleDirectoryReader,
    GPTSimpleVectorIndex,
    LLMPredictor,
    PromptHelper
)


def construct_index(db_path):
    max_input_size = 4096
    num_outputs = 512
    max_chunk_overlap = 20
    chunk_size_limit = 600

    prompt_helper = PromptHelper(
        max_input_size,
        num_outputs,
        max_chunk_overlap,
        chunk_size_limit=chunk_size_limit
    )

    llm = ChatOpenAI(
        temperature=0.7,
        model_name="gpt-3.5-turbo",
        max_tokens=num_outputs
    )

    llm_predictor = LLMPredictor(llm)

    # get documents for learn:
    documents = SimpleDirectoryReader(db_path).load_data()

    index = GPTSimpleVectorIndex(
        documents,
        llm_predictor=llm_predictor,
        prompt_helper=prompt_helper
    )

    index_file = db_path + "/index.json"
    index.save_to_disk(index_file)

    return index
